@@ -2,4 +2,9 @@
 //
 // This is the mod.rs file that is in control of the dev section of the kernel.
 
+
+// Drivers
 pub mod drivers;
+
+// Keyboard support
+pub mod kbd;
